/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

/**
 * <p>
 *  <code>ClassUtils</code> is a Zeus utility class that provides
 *    methods that deal with the various classes and types that
 *    may be used in data binding. Specifically, this will deal
 *    with the <code>String</code> Java types that 
 *    <code>{@link org.enhydra.zeus.Generator}</code>s deal with,
 *    and relate them to Java <code>Class</code> objects.
 * </p>
 *
 * @author Brett McLaughlin
 * @version 1.0
 */
public class ClassUtils {

    /**
     * <p>
     *  This will determine if the supplied Java type (in
     *    <code>String</code> form) is one of the Java
     *    <code>Collection</code> classes.
     * </p>
     *
     * @param javaType the <code>String</code> name of the Java
     *        type to check for.
     * @return <code>boolean</code> - whether the class is a
     *         Java <code>Collection</code>.
     */
    public static boolean isCollectionClass(String javaType) {
        // Since all classes are fully qualified, check for java.util package
        // XXX: This will go away if we ever do imports!!
        if (javaType.indexOf("java.util") == -1) {
            return false;
        }
        
        // Check for the specific Collection names, in order of commonality
        if (javaType.indexOf("Collection") != -1) {
            return true;
        } else if (javaType.indexOf("List") != -1) {
            return true;            
        } else if (javaType.indexOf("LinkedList") != -1) {
            return true;
        } else if (javaType.indexOf("ArrayList") != -1) {
            return true;
        } else if (javaType.indexOf("Vector") != -1) {
            return true;
        } else if (javaType.indexOf("Stack") != -1) {
            return true;
        } else if (javaType.indexOf("Set") != -1) {
            return true;  
        } else if (javaType.indexOf("SortedSet") != -1) {
            return true;
        } else if (javaType.indexOf("HashSet") != -1) {
            return true;                 
        } else if (javaType.indexOf("TreeSet") != -1) {
            return true;                 
        }
        
        return false;                                                
    }
}